@@ -14,7 +14,7 @@ use core::str;
 ///
 /// Can store at most `u32::MAX` strings, the accumulated length
 /// of these strings can be at most `u32::MAX`.
-#[derive(Debug, Default, Eq, PartialEq)]
+#[derive(Debug, Default, Eq, PartialEq, Clone, Hash)]
 pub struct Strings {
     strs: Vec<u8>,
     ends: Vec<u32>,
@@ -117,7 +117,7 @@ impl<'a> IntoIterator for &'a Strings {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct StringsIter<'a> {
     strings: &'a Strings,
     ends_iter: slice::Iter<'a, u32>,
